==> openejb-jee-4.0.0-sources.jar: org/apache/openejb/jee/was/v6/ejb/TransactionAttributeEnum.java <==
/**
 * Licensed to the Apache Software Foundation (ASF) under one or more
 *   contributor license agreements.  See the NOTICE file distributed with
 *   this work for additional information regarding copyright ownership.
 *   The ASF licenses this file to You under the Apache License, Version 2.0
 *   (the "License"); you may not use this file except in compliance with
 *   the License.  You may obtain a copy of the License at
 *  
 *       http://www.apache.org/licenses/LICENSE-2.0
 *  
 *    Unless required by applicable law or agreed to in writing, software
 *    distributed under the License is distributed on an "AS IS" BASIS,
 *    WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *    See the License for the specific language governing permissions and
 *    limitations under the License.
 */
package org.apache.openejb.jee.was.v6.ejb;

import javax.xml.bind.annotation.XmlEnum;
import javax.xml.bind.annotation.XmlEnumValue;

/**
 * <p>
 * Java class for TransactionAttributeType.
 * 
 * <p>
 * The following schema fragment specifies the expected content contained within
 * this class.
 * <p>
 * 
 * <pre>
 * &lt;simpleType name="TransactionAttributeType">
 *   &lt;restriction base="{http://www.w3.org/2001/XMLSchema}NCName">
 *     &lt;enumeration value="NotSupported"/>
 *     &lt;enumeration value="Supports"/>
 *     &lt;enumeration value="Required"/>
 *     &lt;enumeration value="RequiresNew"/>
 *     &lt;enumeration value="Mandatory"/>
 *     &lt;enumeration value="Never"/>
 *   &lt;/restriction>
 * &lt;/simpleType>
 * </pre>
 * 
 */
@XmlEnum
public enum TransactionAttributeEnum {

	@XmlEnumValue("NotSupported")
	NOT_SUPPORTED("NotSupported"), @XmlEnumValue("Supports")
	SUPPORTS("Supports"), @XmlEnumValue("Required")
	REQUIRED("Required"), @XmlEnumValue("RequiresNew")
	REQUIRES_NEW("RequiresNew"), @XmlEnumValue("Mandatory")
	MANDATORY("Mandatory"), @XmlEnumValue("Never")
	NEVER("Never");
	private final String value;

	TransactionAttributeEnum(String v) {
		value = v;
	}

	public String value() {
		return value;
	}

	public static TransactionAttributeEnum fromValue(String v) {
		for (TransactionAttributeEnum c : TransactionAttributeEnum.values()) {
			if (c.value.equals(v)) {
				return c;
			}
		}
		throw new IllegalArgumentException(v.toString());
	}

}

==> openejb-jee-4.7.0-sources.jar: org/apache/openejb/jee/was/v6/ejb/TransactionAttributeEnum.java <==
/**
 * Licensed to the Apache Software Foundation (ASF) under one or more
 *   contributor license agreements.  See the NOTICE file distributed with
 *   this work for additional information regarding copyright ownership.
 *   The ASF licenses this file to You under the Apache License, Version 2.0
 *   (the "License"); you may not use this file except in compliance with
 *   the License.  You may obtain a copy of the License at
 *
 *       http://www.apache.org/licenses/LICENSE-2.0
 *
 *    Unless required by applicable law or agreed to in writing, software
 *    distributed under the License is distributed on an "AS IS" BASIS,
 *    WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *    See the License for the specific language governing permissions and
 *    limitations under the License.
 */
package org.apache.openejb.jee.was.v6.ejb;

import javax.xml.bind.annotation.XmlEnum;
import javax.xml.bind.annotation.XmlEnumValue;

/**
 * <p/>
 * Java class for TransactionAttributeType.
 * <p/>
 * <p/>
 * The following schema fragment specifies the expected content contained within
 * this class.
 * <p/>
 * <p/>
 * <pre>
 * &lt;simpleType name="TransactionAttributeType">
 *   &lt;restriction base="{http://www.w3.org/2001/XMLSchema}NCName">
 *     &lt;enumeration value="NotSupported"/>
 *     &lt;enumeration value="Supports"/>
 *     &lt;enumeration value="Required"/>
 *     &lt;enumeration value="RequiresNew"/>
 *     &lt;enumeration value="Mandatory"/>
 *     &lt;enumeration value="Never"/>
 *   &lt;/restriction>
 * &lt;/simpleType>
 * </pre>
 */
@XmlEnum
public enum TransactionAttributeEnum {

    @XmlEnumValue("NotSupported")
    NOT_SUPPORTED("NotSupported"), @XmlEnumValue("Supports")
    SUPPORTS("Supports"), @XmlEnumValue("Required")
    REQUIRED("Required"), @XmlEnumValue("RequiresNew")
    REQUIRES_NEW("RequiresNew"), @XmlEnumValue("Mandatory")
    MANDATORY("Mandatory"), @XmlEnumValue("Never")
    NEVER("Never");
    private final String value;

    TransactionAttributeEnum(final String v) {
        value = v;
    }

    public String value() {
        return value;
    }

    public static TransactionAttributeEnum fromValue(final String v) {
        for (final TransactionAttributeEnum c : TransactionAttributeEnum.values()) {
            if (c.value.equals(v)) {
                return c;
            }
        }
        throw new IllegalArgumentException(v.toString());
    }

}
